@@ -16,11 +16,12 @@
  *
  **********************************************************************/
 
-#ifndef GEOS_IDX_CHAIN_MONOTONECHAIN_H
-#define GEOS_IDX_CHAIN_MONOTONECHAIN_H
+#pragma once
 
 #include <geos/export.h>
+#include <geos/geom/CoordinateSequence.h> // for inline
 #include <geos/geom/Envelope.h> // for inline
+#include <geos/geom/LineSegment.h> // for inline
 
 #include <memory> // for unique_ptr
 
@@ -100,8 +101,8 @@ public:
     ~MonotoneChain() = default;
 
     /// Returned envelope is owned by this class
-    const geom::Envelope& getEnvelope();
-    const geom::Envelope& getEnvelope(double expansionDistance);
+    const geom::Envelope& getEnvelope() const;
+    const geom::Envelope& getEnvelope(double expansionDistance) const;
 
     size_t
     getStartIndex() const
@@ -119,7 +120,10 @@ public:
      *  Set given LineSegment with points of the segment starting
      *  at the given index.
      */
-    void getLineSegment(std::size_t index, geom::LineSegment& ls) const;
+    void getLineSegment(std::size_t index, geom::LineSegment& ls) const {
+        pts->getAt(index, ls.p0);
+        pts->getAt(index + 1, ls.p1);
+    }
 
     /**
      * Return the subsequence of coordinates forming this chain.
@@ -133,28 +137,16 @@ public:
      * the searchEnvelope, and process them
      */
     void select(const geom::Envelope& searchEnv,
-                MonotoneChainSelectAction& mcs);
+                MonotoneChainSelectAction& mcs) const;
 
-    void computeOverlaps(MonotoneChain* mc,
-                         MonotoneChainOverlapAction* mco);
+    void computeOverlaps(const MonotoneChain* mc,
+                         MonotoneChainOverlapAction* mco) const;
 
-    void computeOverlaps(MonotoneChain* mc, double overlapTolerance,
-                         MonotoneChainOverlapAction* mco);
-
-    void
-    setId(int nId)
-    {
-        id = nId;
-    }
-
-    inline int
-    getId() const
-    {
-        return id;
-    }
+    void computeOverlaps(const MonotoneChain* mc, double overlapTolerance,
+                         MonotoneChainOverlapAction* mco) const;
 
     void*
-    getContext()
+    getContext() const
     {
         return context;
     }
@@ -162,51 +154,47 @@ public:
 private:
 
     void computeSelect(const geom::Envelope& searchEnv,
-                       size_t start0,
-                       size_t end0,
-                       MonotoneChainSelectAction& mcs);
+                       std::size_t start0,
+                       std::size_t end0,
+                       MonotoneChainSelectAction& mcs) const;
 
-    void computeOverlaps(std::size_t start0, std::size_t end0, MonotoneChain& mc,
+    void computeOverlaps(std::size_t start0, std::size_t end0, const MonotoneChain& mc,
                          std::size_t start1, std::size_t end1,
                          double overlapTolerance,
-                         MonotoneChainOverlapAction& mco);
+                         MonotoneChainOverlapAction& mco) const;
 
-    bool overlaps(size_t start0, size_t end0,
-                  const MonotoneChain& mc, size_t start1, size_t end1,
-                  double overlapTolerance) const;
+    bool overlaps(std::size_t start0, std::size_t end0,
+                  const MonotoneChain& mc, std::size_t start1, std::size_t end1,
+                  double overlapTolerance) const {
+        if (overlapTolerance > 0.0) {
+            return overlaps(pts->getAt(start0), pts->getAt(end0),
+                            mc.pts->getAt(start1), mc.pts->getAt(end1), overlapTolerance);
+        }
+        return geom::Envelope::intersects(pts->getAt(start0), pts->getAt(end0),
+                                          mc.pts->getAt(start1), mc.pts->getAt(end1));
+    }
 
-    bool overlaps(const geom::Coordinate& p1, const geom::Coordinate& p2,
+    static bool overlaps(const geom::Coordinate& p1, const geom::Coordinate& p2,
                   const geom::Coordinate& q1, const geom::Coordinate& q2,
-                  double overlapTolerance) const;
+                  double overlapTolerance);
 
     /// Externally owned
-    const geom::CoordinateSequence& pts;
+    const geom::CoordinateSequence* pts;
 
     /// user-defined information
     void* context;
 
     /// Index of chain start vertex into the CoordinateSequence, 0 based.
-    size_t start;
+    std::size_t start;
 
     /// Index of chain end vertex into the CoordinateSequence, 0 based.
-    size_t end;
+    std::size_t end;
 
     /// Owned by this class
-    geom::Envelope env;
-    bool envIsSet;
-
-    /// useful for optimizing chain comparisons
-    int id;
-
-
-    // Declare type as noncopyable
-    MonotoneChain(const MonotoneChain& other) = delete;
-    MonotoneChain& operator=(const MonotoneChain& rhs) = delete;
+    mutable geom::Envelope env;
 };
 
 } // namespace geos::index::chain
 } // namespace geos::index
 } // namespace geos
 
-#endif // GEOS_IDX_CHAIN_MONOTONECHAIN_H
-
