@@ -17,13 +17,13 @@
  *
  **********************************************************************/
 
-#ifndef GEOS_TRIANGULATE_QUADEDGE_QUADEDGESUBDIVISION_H
-#define GEOS_TRIANGULATE_QUADEDGE_QUADEDGESUBDIVISION_H
+#pragma once
 
 #include <memory>
 #include <list>
 #include <stack>
 #include <unordered_set>
+#include <array>
 #include <vector>
 
 #include <geos/geom/MultiLineString.h>
@@ -52,6 +52,9 @@ class TriangleVisitor;
 
 const double EDGE_COINCIDENCE_TOL_FACTOR = 1000;
 
+//-- Frame size factor for initializing subdivision frame.  Larger is more robust
+const double FRAME_SIZE_FACTOR = 100;
+
 /** \brief
  * A class that contains the [QuadEdges](@ref QuadEdge) representing a planar
  * subdivision that models a triangulation.
@@ -360,7 +363,7 @@ private:
      *
      * Only one visitor is allowed to be active at a time, so this is safe.
      */
-    QuadEdge* triEdges[3];
+    std::array<QuadEdge*, 3> m_triEdges;
 
     /** \brief
      * Resets the `visited` flag of each `QuadEdge` prior to iteration, if necessary.
@@ -378,7 +381,7 @@ private:
      * @return `null` if the triangle should not be visited (for instance, if it is
      *         outer)
      */
-    QuadEdge** fetchTriangleToVisit(QuadEdge* edge, QuadEdgeStack& edgeStack, bool includeFrame);
+    std::array<QuadEdge*, 3>* fetchTriangleToVisit(QuadEdge* edge, QuadEdgeStack& edgeStack, bool includeFrame);
 
     /** \brief
      * Gets the coordinates for each triangle in the subdivision as an array.
@@ -514,5 +517,3 @@ public:
 } //namespace geos.triangulate.quadedge
 } //namespace geos.triangulate
 } //namespace goes
-
-#endif //GEOS_TRIANGULATE_QUADEDGE_QUADEDGESUBDIVISION_H
