@@ -33,11 +33,17 @@
 #include <typeinfo>
 #include <algorithm>
 
-#ifndef GEOS_INLINE
-# include "geos/algorithm/ConvexHull.inl"
-#endif
 
-using namespace geos::geom;
+using geos::geom::Geometry;
+using geos::geom::GeometryFactory;
+using geos::geom::Coordinate;
+using geos::geom::Point;
+using geos::geom::Polygon;
+using geos::geom::LineString;
+using geos::geom::LinearRing;
+using geos::geom::CoordinateSequence;
+using geos::geom::CoordinateSequenceFactory;
+
 
 namespace geos {
 namespace algorithm { // geos.algorithm
@@ -54,15 +60,10 @@ private:
 
     const Coordinate* origin;
 
-    int
+    static int
     polarCompare(const Coordinate* o, const Coordinate* p,
                  const Coordinate* q)
     {
-        double dxp = p->x - o->x;
-        double dyp = p->y - o->y;
-        double dxq = q->x - o->x;
-        double dyq = q->y - o->y;
-
         int orient = Orientation::index(*o, *p, *q);
 
         if(orient == Orientation::COUNTERCLOCKWISE) {
@@ -72,15 +73,28 @@ private:
             return -1;
         }
 
-        // points are collinear - check distance
-        double op = dxp * dxp + dyp * dyp;
-        double oq = dxq * dxq + dyq * dyq;
-        if(op < oq) {
-            return -1;
-        }
-        if(op > oq) {
-            return 1;
-        }
+        /**
+         * The points are collinear,
+         * so compare based on distance from the origin.
+         * The points p and q are >= to the origin,
+         * so they lie in the closed half-plane above the origin.
+         * If they are not in a horizontal line,
+         * the Y ordinate can be tested to determine distance.
+         * This is more robust than computing the distance explicitly.
+         */
+        if (p->y > q->y) return 1;
+        if (p->y < q->y) return -1;
+
+        /**
+         * The points lie in a horizontal line, which should also contain the origin
+         * (since they are collinear).
+         * Also, they must be above the origin.
+         * Use the X ordinate to determine distance.
+         */
+        if (p->x > q->x) return 1;
+        if (p->x < q->x) return -1;
+
+      // Assert: p = q
         return 0;
     }
 
@@ -107,7 +121,7 @@ ConvexHull::toCoordinateSequence(Coordinate::ConstVect& cv)
 
     std::vector<Coordinate> vect(cv.size());
 
-    for(size_t i = 0; i < cv.size(); ++i) {
+    for(std::size_t i = 0; i < cv.size(); ++i) {
         vect[i] = *(cv[i]); // Coordinate copy
     }
 
@@ -122,7 +136,7 @@ ConvexHull::computeOctPts(const Coordinate::ConstVect& p_inputPts,
     // Initialize all slots with first input coordinate
     pts = Coordinate::ConstVect(8, p_inputPts[0]);
 
-    for(size_t i = 1, n = p_inputPts.size(); i < n; ++i) {
+    for(std::size_t i = 1, n = p_inputPts.size(); i < n; ++i) {
         if(p_inputPts[i]->x < pts[0]->x) {
             pts[0] = p_inputPts[i];
         }
@@ -199,7 +213,7 @@ ConvexHull::reduce(Coordinate::ConstVect& pts)
      *
      * @@TIP: there should be a std::algo for this
      */
-    for(size_t i = 0, n = pts.size(); i < n; ++i) {
+    for(std::size_t i = 0, n = pts.size(); i < n; ++i) {
         if(!PointLocation::isInRing(*(pts[i]), polyPts)) {
             reducedSet.insert(pts[i]);
         }
@@ -216,7 +230,7 @@ ConvexHull::reduce(Coordinate::ConstVect& pts)
 void
 ConvexHull::padArray3(geom::Coordinate::ConstVect& pts)
 {
-    for(size_t i = pts.size(); i < 3; ++i) {
+    for(std::size_t i = pts.size(); i < 3; ++i) {
         pts.push_back(pts[0]);
     }
 }
@@ -224,7 +238,7 @@ ConvexHull::padArray3(geom::Coordinate::ConstVect& pts)
 std::unique_ptr<Geometry>
 ConvexHull::getConvexHull()
 {
-    size_t nInputPts = inputPts.size();
+    std::size_t nInputPts = inputPts.size();
 
     if(nInputPts == 0) { // Return an empty geometry
         return geomFactory->createEmptyGeometry();
@@ -269,7 +283,7 @@ ConvexHull::preSort(Coordinate::ConstVect& pts)
     // find the lowest point in the set. If two or more points have
     // the same minimum y coordinate choose the one with the minimum x.
     // This focal point is put in array location pts[0].
-    for(size_t i = 1, n = pts.size(); i < n; ++i) {
+    for(std::size_t i = 1, n = pts.size(); i < n; ++i) {
         const Coordinate* p0 = pts[0]; // this will change
         const Coordinate* pi = pts[i];
         if((pi->y < p0->y) || ((pi->y == p0->y) && (pi->x < p0->x))) {
@@ -292,7 +306,7 @@ ConvexHull::grahamScan(const Coordinate::ConstVect& c,
     ps.push_back(c[1]);
     ps.push_back(c[2]);
 
-    for(size_t i = 3, n = c.size(); i < n; ++i) {
+    for(std::size_t i = 3, n = c.size(); i < n; ++i) {
         const Coordinate* p = ps.back();
         ps.pop_back();
         while(!ps.empty() &&
@@ -358,7 +372,7 @@ void
 ConvexHull::cleanRing(const Coordinate::ConstVect& original,
                       Coordinate::ConstVect& cleaned)
 {
-    size_t npts = original.size();
+    std::size_t npts = original.size();
 
     const Coordinate* last = original[npts - 1];
 
@@ -367,7 +381,7 @@ ConvexHull::cleanRing(const Coordinate::ConstVect& original,
     assert(original[0]->equals2D(*last));
 
     const Coordinate* prev = nullptr;
-    for(size_t i = 0; i < npts - 1; ++i) {
+    for(std::size_t i = 0; i < npts - 1; ++i) {
         const Coordinate* curr = original[i];
         const Coordinate* next = original[i + 1];
 
@@ -391,4 +405,3 @@ ConvexHull::cleanRing(const Coordinate::ConstVect& original,
 
 } // namespace geos.algorithm
 } // namespace geos
-
