@@ -13,18 +13,22 @@
  *
  **********************************************************************/
 
-#include <geos/geom/CoordinateSequenceFactory.h>
 #include <geos/geom/CoordinateArraySequenceFactory.h>
 
-#ifndef GEOS_INLINE
-# include "geos/geom/CoordinateArraySequenceFactory.inl"
-#endif
 
 namespace geos {
 namespace geom { // geos::geom
 
 static CoordinateArraySequenceFactory defaultCoordinateSequenceFactory;
 
+std::unique_ptr<CoordinateSequence>
+CoordinateArraySequenceFactory::create() const
+{
+    return std::unique_ptr<CoordinateSequence>(
+            new CoordinateArraySequence(
+                    reinterpret_cast<std::vector<Coordinate>*>(0), 0));
+}
+
 const CoordinateSequenceFactory*
 CoordinateArraySequenceFactory::instance()
 {
