@@ -19,28 +19,22 @@
  **********************************************************************/
 
 #include <geos/geomgraph/GeometryGraph.h>
-#include <geos/geom/MultiLineString.h>
-#include <geos/geom/LineString.h>
 #include <geos/geom/GeometryFactory.h>
-#include <geos/geom/Dimension.h>
+#include <geos/geom/MultiLineString.h>
+#include <geos/operation/BoundaryOp.h>
 
 #include <vector>
 #include <cassert>
 
-#ifndef GEOS_INLINE
-# include "geos/geom/MultiLineString.inl"
-#endif
-
-using namespace std;
-using namespace geos::algorithm;
-//using namespace geos::operation;
-using namespace geos::geomgraph;
+using geos::geom::GeometryFactory;
+using geos::geom::MultiLineString;
+using geos::geomgraph::GeometryGraph;
 
 namespace geos {
 namespace geom { // geos::geom
 
 /*protected*/
-MultiLineString::MultiLineString(vector<Geometry*>* newLines,
+MultiLineString::MultiLineString(std::vector<Geometry*>* newLines,
                                  const GeometryFactory* factory)
     :
     GeometryCollection(newLines, factory)
@@ -72,7 +66,7 @@ MultiLineString::getBoundaryDimension() const
     return 0;
 }
 
-string
+std::string
 MultiLineString::getGeometryType() const
 {
     return "MultiLineString";
@@ -85,7 +79,7 @@ MultiLineString::isClosed() const
         return false;
     }
     for(const auto& g : geometries) {
-        LineString* ls = dynamic_cast<LineString*>(g.get());
+        const LineString* ls = detail::down_cast<const LineString*>(g.get());
         if(! ls->isClosed()) {
             return false;
         }
@@ -96,44 +90,39 @@ MultiLineString::isClosed() const
 std::unique_ptr<Geometry>
 MultiLineString::getBoundary() const
 {
-    if(isEmpty()) {
-        return getFactory()->createGeometryCollection();
-    }
-
-    GeometryGraph gg(0, this);
-    CoordinateSequence* pts = gg.getBoundaryPoints();
-    return std::unique_ptr<Geometry>(getFactory()->createMultiPoint(*pts));
+    operation::BoundaryOp bop(*this);
+    return bop.getBoundary();
 }
 
-bool
-MultiLineString::equalsExact(const Geometry* other, double tolerance) const
-{
-    if(!isEquivalentClass(other)) {
-        return false;
-    }
-    return GeometryCollection::equalsExact(other, tolerance);
-}
 GeometryTypeId
 MultiLineString::getGeometryTypeId() const
 {
     return GEOS_MULTILINESTRING;
 }
 
-std::unique_ptr<Geometry>
-MultiLineString::reverse() const
+MultiLineString*
+MultiLineString::reverseImpl() const
 {
     if(isEmpty()) {
-        return clone();
+        return clone().release();
     }
 
-    size_t nLines = geometries.size();
-    std::vector<std::unique_ptr<Geometry>> revLines(nLines);
+    std::vector<std::unique_ptr<Geometry>> reversed(geometries.size());
 
-    for(size_t i = 0; i < nLines; ++i) {
-        const LineString* iLS = static_cast<LineString*>(geometries[i].get());
-        revLines[nLines - 1 - i] = iLS->reverse();
-    }
-    return getFactory()->createMultiLineString(std::move(revLines));
+    std::transform(geometries.begin(),
+                   geometries.end(),
+                   reversed.begin(),
+                   [](const std::unique_ptr<Geometry> & g) {
+                       return g->reverse();
+                   });
+
+    return getFactory()->createMultiLineString(std::move(reversed)).release();
+}
+
+const LineString*
+MultiLineString::getGeometryN(std::size_t i) const
+{
+    return static_cast<const LineString*>(geometries[i].get());
 }
 
 } // namespace geos::geom
