@@ -37,7 +37,7 @@
 #define GEOS_DEBUG 0
 #endif
 
-using namespace std;
+
 using namespace geos::geomgraph;
 using namespace geos::algorithm;
 using namespace geos::geom;
@@ -53,31 +53,8 @@ namespace buffer { // geos.operation.buffer
 class DepthSegment {
 
 private:
-
     geom::LineSegment upwardSeg;
 
-    /*
-     * Compare two collinear segments for left-most ordering.
-     * If segs are vertical, use vertical ordering for comparison.
-     * If segs are equal, return 0.
-     * Segments are assumed to be directed so that the second
-     * coordinate is >= to the first
-     * (e.g. up and to the right).
-     *
-     * @param seg0 a segment to compare
-     * @param seg1 a segment to compare
-     * @return
-     */
-    static int
-    compareX(const geom::LineSegment* seg0, const geom::LineSegment* seg1)
-    {
-        int compare0 = seg0->p0.compareTo(seg1->p0);
-        if(compare0 != 0) {
-            return compare0;
-        }
-        return seg0->p1.compareTo(seg1->p1);
-    }
-
 public:
 
     int leftDepth;
@@ -107,9 +84,21 @@ public:
     int
     compareTo(const DepthSegment& other) const
     {
-        /*
-         * try and compute a determinate orientation for the segments.
-         * Test returns 1 if other is left of this (i.e. this > other)
+        /**
+         * If segment envelopes do not overlap, then
+         * can use standard segment lexicographic ordering.
+         */
+        if (upwardSeg.minX() >= other.upwardSeg.maxX()
+            || upwardSeg.maxX() <= other.upwardSeg.minX()
+            || upwardSeg.minY() >= other.upwardSeg.maxY()
+            || upwardSeg.maxY() <= other.upwardSeg.minY()) {
+            return upwardSeg.compareTo(other.upwardSeg);
+        };
+
+        /**
+         * Otherwise if envelopes overlap, use relative segment orientation.
+         *
+         * Collinear segments should be evaluated by previous logic
          */
         int orientIndex = upwardSeg.orientationIndex(&(other.upwardSeg));
 
@@ -129,12 +118,16 @@ public:
             return orientIndex;
         }
 
-        // otherwise, segs must be collinear - sort based on minimum X value
-        return compareX(&upwardSeg, &(other.upwardSeg));
+        /**
+         * If segment envelopes overlap and they are collinear,
+         * since segments do not cross they must be equal.
+         */
+        // assert: segments are equal
+        return 0;
     }
 };
 
-struct DepthSegmentLessThen {
+struct DepthSegmentLessThan {
     bool
     operator()(const DepthSegment* first, const DepthSegment* second)
     {
@@ -149,13 +142,11 @@ struct DepthSegmentLessThen {
     }
 };
 
-
-
 /*public*/
 int
 SubgraphDepthLocater::getDepth(const Coordinate& p)
 {
-    vector<DepthSegment*> stabbedSegments;
+    std::vector<DepthSegment*> stabbedSegments;
     findStabbedSegments(p, stabbedSegments);
 
     // if no segments on stabbing line subgraph must be outside all others
@@ -164,14 +155,14 @@ SubgraphDepthLocater::getDepth(const Coordinate& p)
     }
 
     DepthSegment *ds = *std::min_element(stabbedSegments.begin(),
-        stabbedSegments.end(), DepthSegmentLessThen());
+        stabbedSegments.end(), DepthSegmentLessThan());
     int ret = ds->leftDepth;
 
 #if GEOS_DEBUG
-    cerr << "SubgraphDepthLocater::getDepth(" << p.toString() << "): " << ret << endl;
+    std::cerr << "SubgraphDepthLocater::getDepth(" << p.toString() << "): " << ret << std::endl;
 #endif
 
-    for(vector<DepthSegment*>::iterator
+    for(std::vector<DepthSegment*>::iterator
             it = stabbedSegments.begin(), itEnd = stabbedSegments.end();
             it != itEnd;
             ++it) {
@@ -186,8 +177,8 @@ void
 SubgraphDepthLocater::findStabbedSegments(const Coordinate& stabbingRayLeftPt,
         std::vector<DepthSegment*>& stabbedSegments)
 {
-    size_t size = subgraphs->size();
-    for(size_t i = 0; i < size; ++i) {
+    std::size_t size = subgraphs->size();
+    for(std::size_t i = 0; i < size; ++i) {
         BufferSubgraph* bsg = (*subgraphs)[i];
 
         // optimization - don't bother checking subgraphs
@@ -209,15 +200,15 @@ SubgraphDepthLocater::findStabbedSegments(const Coordinate& stabbingRayLeftPt,
 void
 SubgraphDepthLocater::findStabbedSegments(
     const Coordinate& stabbingRayLeftPt,
-    vector<DirectedEdge*>* dirEdges,
-    vector<DepthSegment*>& stabbedSegments)
+    std::vector<DirectedEdge*>* dirEdges,
+    std::vector<DepthSegment*>& stabbedSegments)
 {
 
     /*
      * Check all forward DirectedEdges only. This is still general,
      * because each Edge has a forward DirectedEdge.
      */
-    for(size_t i = 0, n = dirEdges->size(); i < n; ++i) {
+    for(std::size_t i = 0, n = dirEdges->size(); i < n; ++i) {
         DirectedEdge* de = (*dirEdges)[i];
         if(!de->isForward()) {
             continue;
@@ -231,26 +222,26 @@ void
 SubgraphDepthLocater::findStabbedSegments(
     const Coordinate& stabbingRayLeftPt,
     DirectedEdge* dirEdge,
-    vector<DepthSegment*>& stabbedSegments)
+    std::vector<DepthSegment*>& stabbedSegments)
 {
     const CoordinateSequence* pts = dirEdge->getEdge()->getCoordinates();
 
 // It seems that LineSegment is *very* slow... undef this
 // to see yourself
 // LineSegment has been refactored to be mostly inline, still
-// it makes copies of the given coordinates, while the 'non-LineSemgent'
+// it makes copies of the given coordinates, while the 'non-LineSegment'
 // based code below uses pointers instead. I'll kip the SKIP_LS
 // defined until LineSegment switches to Coordinate pointers instead.
 //
 #define SKIP_LS 1
 
     auto n = pts->getSize() - 1;
-    for(size_t i = 0; i < n; ++i) {
+    for(std::size_t i = 0; i < n; ++i) {
 #ifndef SKIP_LS
         seg.p0 = pts->getAt(i);
         seg.p1 = pts->getAt(i + 1);
 #if GEOS_DEBUG
-        cerr << " SubgraphDepthLocater::findStabbedSegments: segment " << i
+        std::cerr << " SubgraphDepthLocater::findStabbedSegments: segment " << i
              << " (" << seg << ") ";
 #endif
 
@@ -267,7 +258,7 @@ SubgraphDepthLocater::findStabbedSegments(
         {
             seg.reverse();
 #if GEOS_DEBUG
-            cerr << " reverse (" << seg << ") ";
+            std::cerr << " reverse (" << seg << ") ";
 #endif
         }
 #else
@@ -281,13 +272,13 @@ SubgraphDepthLocater::findStabbedSegments(
         // skip segment if it is left of the stabbing line
         // skip if segment is above or below stabbing line
 #ifndef SKIP_LS
-        double maxx = max(seg.p0.x, seg.p1.x);
+        double maxx = std::max(seg.p0.x, seg.p1.x);
 #else
-        double maxx = max(low->x, high->x);
+        double maxx = std::max(low->x, high->x);
 #endif
         if(maxx < stabbingRayLeftPt.x) {
 #if GEOS_DEBUG
-            cerr << " segment is left to stabbing line, skipping " << endl;
+            std::cerr << " segment is left to stabbing line, skipping " << std::endl;
 #endif
             continue;
         }
@@ -301,7 +292,7 @@ SubgraphDepthLocater::findStabbedSegments(
 #endif
         {
 #if GEOS_DEBUG
-            cerr << " segment is horizontal, skipping " << endl;
+            std::cerr << " segment is horizontal, skipping " << std::endl;
 #endif
             continue;
         }
@@ -316,7 +307,7 @@ SubgraphDepthLocater::findStabbedSegments(
 #endif
         {
 #if GEOS_DEBUG
-            cerr << " segment above or below stabbing line, skipping " << endl;
+            std::cerr << " segment above or below stabbing line, skipping " << std::endl;
 #endif
             continue;
         }
@@ -329,7 +320,7 @@ SubgraphDepthLocater::findStabbedSegments(
 #endif
                               stabbingRayLeftPt) == Orientation::RIGHT) {
 #if GEOS_DEBUG
-            cerr << " stabbing ray right of segment, skipping" << endl;
+            std::cerr << " stabbing ray right of segment, skipping" << std::endl;
 #endif
             continue;
         }
@@ -348,7 +339,7 @@ SubgraphDepthLocater::findStabbedSegments(
 #endif
 
 #if GEOS_DEBUG
-        cerr << " depth: " << depth << endl;
+        std::cerr << " depth: " << depth << std::endl;
 #endif
 
 #ifdef SKIP_LS
