@@ -36,6 +36,7 @@
 #include <geos/geom/Location.h>
 #include <geos/geom/Geometry.h>
 #include <geos/util/Interrupt.h>
+#include <geos/util/TopologyException.h>
 
 #include <algorithm>
 
@@ -141,6 +142,7 @@ OverlayNG::geomunion(const Geometry* geom, const PrecisionModel* pm, noding::Nod
 {
     OverlayNG ov(geom, pm);
     ov.setNoder(noder);
+    ov.setStrictMode(true);
     return ov.getResult();
 }
 
@@ -185,7 +187,7 @@ OverlayNG::getResult()
     w.setOutputDimension(3);
     w.setTrim(true);
 
-    std::cout << "Before populatingZ: " << w.write(result.get()) << std::endl;
+    std::cerr << "Before populatingZ: " << w.write(result.get()) << std::endl;
 #endif
 
     /**
@@ -195,7 +197,7 @@ OverlayNG::getResult()
     elevModel->populateZ(*result);
 
 #if GEOS_DEBUG
-    std::cout << " After populatingZ: " << w.write(result.get()) << std::endl;
+    std::cerr << " After populatingZ: " << w.write(result.get()) << std::endl;
 #endif
 
     return result;
@@ -266,7 +268,22 @@ OverlayNG::computeEdgeOverlay()
     }
 
     GEOS_CHECK_FOR_INTERRUPTS();
-    return extractResult(opCode, &graph);
+    std::unique_ptr<Geometry> result = extractResult(opCode, &graph);
+
+    /**
+     * Heuristic check on result area.
+     * Catches cases where noding causes vertex to move
+     * and make topology graph area "invert".
+     */
+    if (OverlayUtil::isFloating(pm)) {
+        bool isAreaConsistent = OverlayUtil::isResultAreaConsistent(
+            inputGeom.getGeometry(0),
+            inputGeom.getGeometry(1),
+            opCode, result.get());
+        if (! isAreaConsistent)
+            throw util::TopologyException("Result area inconsistent with overlay operation");
+    }
+    return result;
 }
 
 /*private*/
