@@ -42,7 +42,7 @@
 #pragma warning(disable:4355)
 #endif
 
-using namespace std;
+
 using namespace geos::geom;
 
 namespace geos {
@@ -55,9 +55,9 @@ struct Face {
     double envarea = 0.0; // envelope area
     Face* parent = nullptr; /* if this face is an hole of another one, or NULL */
 
-    size_t countParents() const {
+    std::size_t countParents() const {
         const Face* f = this;
-        size_t pcount = 0;
+        std::size_t pcount = 0;
         while ( f->parent ) {
             ++pcount;
             f = f->parent;
@@ -66,6 +66,74 @@ struct Face {
     }
 };
 
+static bool ringsEqualAnyDirection(const LinearRing* r1, const LinearRing* r2)
+{
+
+    const CoordinateSequence *cs1 = r1->getCoordinatesRO();
+    const CoordinateSequence *cs2 = r2->getCoordinatesRO();
+
+    /* Check same number of points */
+    size_t npoints = cs1->size();
+    if ( npoints != cs2->size() )
+    {
+        return false;
+    }
+
+    if ( npoints == 0 ) return true; /* if empty, they are equal */
+
+    /* Check same envelope (probably better avoid, as it'd need to
+     * compute the envelope doing an additional scan for each) */
+    if ( ! r1->getEnvelopeInternal()->equals(r2->getEnvelopeInternal()) )
+    {
+        return false;
+    }
+
+    /* Pretend the rings had one less point, as the last one will be
+     * equal to the first one anyway */
+    --npoints;
+
+    const Coordinate& firstPoint = cs1->getAt(0);
+    size_t offset = CoordinateSequence::indexOf(&firstPoint, cs2);
+    if ( offset == std::numeric_limits<std::size_t>::max() ) return false;
+
+    bool equal = true;
+
+    /* Check equals forward (skip first point, we checked it alread) */
+    for (size_t i=1; i<npoints; ++i)
+    {
+        size_t j = ( i + offset ) % npoints;
+        const Coordinate& c1 = cs1->getAt(i);
+        const Coordinate& c2 = cs2->getAt(j);
+        if ( ! c1.equals(c2) ) {
+            equal = false;
+            break;
+        }
+    }
+
+    if ( equal ) return true;
+
+    /* Check equals backward (skip first point, we checked it already) */
+    equal = true;
+    for (size_t i=1; i<npoints; ++i)
+    {
+        size_t j;
+        if ( i <= offset ) {
+            j = offset - i;
+        } else {
+            j = npoints - ( i - offset );
+        }
+
+        const Coordinate& c1 = cs1->getAt(i);
+        const Coordinate& c2 = cs2->getAt(j);
+        if ( ! c1.equals(c2) ) {
+            equal = false;
+            break;
+        }
+    }
+
+    return equal;
+}
+
 static std::unique_ptr<Face> newFace(const geom::Polygon* p) {
     auto f = std::unique_ptr<Face>(new Face());
     f->poly = p;
@@ -89,24 +157,19 @@ static void findFaceHoles(std::vector<std::unique_ptr<Face>>& faces) {
      * after their shells */
     std::sort(faces.begin(), faces.end(), CompareByEnvarea());
 
-    const size_t nfaces = faces.size();
-    for( size_t i = 0; i < nfaces; ++i ) {
+    const std::size_t nfaces = faces.size();
+    for( std::size_t i = 0; i < nfaces; ++i ) {
         auto& f = faces[i];
-        const size_t nholes = f->poly->getNumInteriorRing();
-        for( size_t h = 0; h < nholes; h++ ) {
+        const std::size_t nholes = f->poly->getNumInteriorRing();
+        for( std::size_t h = 0; h < nholes; h++ ) {
             const auto hole = f->poly->getInteriorRingN(h);
             for( auto j=i+1; j < nfaces; ++j ) {
                 auto& f2 = faces[j];
                 if( f2->parent ) {
                     continue; /* hole already assigned */
                 }
-                const auto f2er = f2->poly->getExteriorRing();
-                /* TODO: can be optimized as the ring would have the
-                *       same vertices, possibly in different order.
-                *       maybe comparing number of points could already be
-                *       useful.
-                */
-                if( f2er->equals(hole) ) {
+                const auto shell = f2->poly->getExteriorRing();
+                if( ringsEqualAnyDirection(shell, hole) ) {
                     f2->parent = f.get();
                     break;
                 }
@@ -116,7 +179,7 @@ static void findFaceHoles(std::vector<std::unique_ptr<Face>>& faces) {
 }
 
 static std::unique_ptr<geom::MultiPolygon> collectFacesWithEvenAncestors(
-    std::vector<std::unique_ptr<Face>>& faces) {
+    const std::vector<std::unique_ptr<Face>>& faces) {
     std::vector<std::unique_ptr<geom::Geometry>> geoms;
     for( auto& face: faces ) {
         if( face->countParents() % 2 ) {
@@ -138,7 +201,7 @@ static void dumpGeometry(const geom::Geometry* geom)
 #endif
 
 /** Return the area built from the constituent linework of the input geometry. */
-unique_ptr<geom::Geometry> BuildArea::build(const geom::Geometry* geom) {
+std::unique_ptr<geom::Geometry> BuildArea::build(const geom::Geometry* geom) {
     Polygonizer polygonizer;
     polygonizer.add(geom);
     auto polys = polygonizer.getPolygons();
@@ -146,7 +209,7 @@ unique_ptr<geom::Geometry> BuildArea::build(const geom::Geometry* geom) {
     // No geometries in collection, early out
     if( polys.empty() ) {
         // TODO don't create new GeometryFactory here
-        auto emptyGeomCollection = unique_ptr<geom::Geometry>(
+        auto emptyGeomCollection = std::unique_ptr<geom::Geometry>(
             GeometryFactory::create()->createGeometryCollection());
         emptyGeomCollection->setSRID(geom->getSRID());
         return emptyGeomCollection;
