@@ -75,62 +75,6 @@ private:
 
 };
 
-/*
- * helper class to transform a map iterator so to return value_type
- * on dereference.
- * TODO: generalize this to be a "ValueIterator" with specializations
- *       for std::map and std::vector
- */
-class LinesMapValueIterator {
-
-    LinesMap::iterator _iter;
-
-public:
-
-    LinesMapValueIterator(LinesMap::iterator iter)
-        :
-        _iter(iter)
-    {
-    }
-
-    // copy ctor
-    LinesMapValueIterator(const LinesMapValueIterator& o)
-        :
-        _iter(o._iter)
-    {
-    }
-
-    // assignment
-    LinesMapValueIterator&
-    operator=(const LinesMapValueIterator& o)
-    {
-        _iter = o._iter;
-        return *this;
-    }
-
-    // ++suffix
-    LinesMapValueIterator&
-    operator++()
-    {
-        ++_iter;
-        return *this;
-    }
-
-    // inequality operator
-    bool
-    operator!=(const LinesMapValueIterator& other) const
-    {
-        return _iter != other._iter;
-    }
-
-    TaggedLineString*
-    operator*()
-    {
-        return _iter->second;
-    }
-};
-
-
 /*public*/
 LineStringTransformer::LineStringTransformer(LinesMap& nMap)
     :
@@ -205,11 +149,12 @@ public:
      * User's constructor.
      * @param nMap - reference to LinesMap instance.
      */
-    LineStringMapBuilderFilter(LinesMap& nMap);
+    LineStringMapBuilderFilter(LinesMap& nMap, std::vector<TaggedLineString*>& tlsVec);
 
 private:
 
     LinesMap& linestringMap;
+    std::vector<TaggedLineString*>& tlsVector;
 
     // Declare type as noncopyable
     LineStringMapBuilderFilter(const LineStringMapBuilderFilter& other) = delete;
@@ -217,9 +162,9 @@ private:
 };
 
 /*public*/
-LineStringMapBuilderFilter::LineStringMapBuilderFilter(LinesMap& nMap)
+LineStringMapBuilderFilter::LineStringMapBuilderFilter(LinesMap& nMap, std::vector<TaggedLineString*>& tlsVec)
     :
-    linestringMap(nMap)
+    linestringMap(nMap), tlsVector(tlsVec)
 {
 }
 
@@ -243,6 +188,7 @@ LineStringMapBuilderFilter::filter_ro(const Geometry* geom)
         delete taggedLine;
         throw util::GEOSException("Duplicated Geometry components detected");
     }
+    tlsVector.push_back(taggedLine);
 }
 
 
@@ -296,7 +242,9 @@ TopologyPreservingSimplifier::getResultGeometry()
     std::unique_ptr<geom::Geometry> result;
 
     try {
-        LineStringMapBuilderFilter lsmbf(linestringMap);
+        //-- vector ensures deterministic simplification order of TaggedLineStrings
+        std::vector<TaggedLineString*> tlsVector;
+        LineStringMapBuilderFilter lsmbf(linestringMap, tlsVector);
         inputGeom->apply_ro(&lsmbf);
 
 #if GEOS_DEBUG
@@ -305,10 +253,7 @@ TopologyPreservingSimplifier::getResultGeometry()
                   << linestringMap.size() << " elements\n";
 #endif
 
-        LinesMapValueIterator begin(linestringMap.begin());
-        LinesMapValueIterator end(linestringMap.end());
-        lineSimplifier->simplify(begin, end);
-
+        lineSimplifier->simplify(tlsVector.begin(), tlsVector.end());
 
 #if GEOS_DEBUG
         std::cerr << "all TaggedLineString simplified\n";
@@ -351,4 +296,3 @@ TopologyPreservingSimplifier::getResultGeometry()
 
 } // namespace geos::simplify
 } // namespace geos
-
