@@ -14,8 +14,8 @@
  **********************************************************************/
 
 
-#ifndef GEOS_BIGTEST_H
-#define GEOS_BIGTEST_H
+#pragma once
+
 
 #include <memory>
 
@@ -35,12 +35,11 @@ class GeometryTestFactory {
 public:
     static geom::Polygon* createBox(geom::GeometryFactory* fact, double minx, double miny, int nSide, double segLen);
     static geom::CoordinateSequence* createBox(double minx, double miny, int nSide, double segLen);
-    static geom::CoordinateSequence* createCircle(double basex, double basey, double size, int nPts);
-    static geom::Polygon* createCircle(geom::GeometryFactory* fact, double basex, double basey, double size, int nPts);
+    static geom::CoordinateSequence* createCircle(double basex, double basey, double size, uint32_t nPts);
+    static geom::Polygon* createCircle(geom::GeometryFactory* fact, double basex, double basey, double size, uint32_t nPts);
     static geom::CoordinateSequence* createSineStar(double basex, double basey, double size, double armLen, int nArms,
             int nPts);
     static geom::Polygon* createSineStar(geom::GeometryFactory* fact, double basex, double basey, double size,
                                          double armLen, int nArms, int nPts);
 };
 
-#endif
