@@ -57,7 +57,7 @@ struct test_robustlineintersection_data {
      */
     void
     checkIntersection(const std::vector<Coordinate>& pt,
-                      size_t expectedIntersectionNum,
+                      std::size_t expectedIntersectionNum,
                       const std::vector<Coordinate>& intPt,
                       double distanceTolerance)
     {
@@ -111,7 +111,7 @@ struct test_robustlineintersection_data {
     void
     checkIntersection(const std::string& wkt1,
                       const std::string& wkt2,
-                      int expectedIntersectionNum,
+                      std::size_t expectedIntersectionNum,
                       const std::string& expectedWKT,
                       double distanceTolerance)
     //throws ParseException
@@ -139,7 +139,7 @@ struct test_robustlineintersection_data {
         std::unique_ptr<CoordinateSequence> cs(g->getCoordinates());
 
         std::vector<Coordinate> intPt;
-        for(size_t i = 0; i < cs->size(); ++i) {
+        for(std::size_t i = 0; i < cs->size(); ++i) {
             intPt.push_back(cs->getAt(i));
         }
 
@@ -150,7 +150,7 @@ struct test_robustlineintersection_data {
     void
     checkIntersection(const std::string& wkt1,
                       const std::string& wkt2,
-                      int expectedIntersectionNum,
+                      std::size_t expectedIntersectionNum,
                       const std::vector<Coordinate>& intPt,
                       double distanceTolerance)
     // throws ParseException
@@ -239,7 +239,7 @@ struct test_robustlineintersection_data {
         li.computeIntersection(pt[0], pt[1], pt[2], pt[3]);
 
         // check that input points are unchanged
-        for(int i = 0; i < 4; i++) {
+        for(std::size_t i = 0; i < 4; i++) {
             ensure_equals(savePt[i], pt[i]);
         }
     }
@@ -381,7 +381,6 @@ void object::test<6>
         0);
 }
 
-#if 0 // fails: finds an intersection (we don't have DD)
 /**
  * Test from Tomas Fa - JTS list 6/13/2012
  *
@@ -399,9 +398,7 @@ void object::test<7>
         "LINESTRING (-5.9 163.1, 76.1 250.7)",
         "LINESTRING (14.6 185.0, 96.6 272.6)");
 }
-#endif // fails
 
-#if 0 // fails: finds an intersection (we don't have DD)
 /**
  * Test from Tomas Fa - JTS list 6/13/2012
  *
@@ -419,7 +416,7 @@ void object::test<8>
         "LINESTRING (-42.0 163.2, 21.2 265.2)",
         "LINESTRING (-26.2 188.7, 37.0 290.7)");
 }
-#endif // fails
+
 
 /**
  * Following cases were failures when using the CentralEndpointIntersector heuristic.
