@@ -3,6 +3,7 @@
 
 #include <tut/tut.hpp>
 // geos
+#include <geos/constants.h>
 #include <geos_c.h>
 // std
 #include <cstdarg>
@@ -10,45 +11,15 @@
 #include <cstdlib>
 #include <cstring>
 
+#include "capi_test_utils.h"
+
 namespace tut {
 //
 // Test Group
 //
 
 // Common data used in test cases.
-struct test_capigeosequals_data {
-    GEOSGeometry* geom1_;
-    GEOSGeometry* geom2_;
-
-    static void
-    notice(const char* fmt, ...)
-    {
-        std::fprintf(stdout, "NOTICE: ");
-
-        va_list ap;
-        va_start(ap, fmt);
-        std::vfprintf(stdout, fmt, ap);
-        va_end(ap);
-
-        std::fprintf(stdout, "\n");
-    }
-
-    test_capigeosequals_data()
-        : geom1_(nullptr), geom2_(nullptr)
-    {
-        initGEOS(notice, notice);
-    }
-
-    ~test_capigeosequals_data()
-    {
-        GEOSGeom_destroy(geom1_);
-        GEOSGeom_destroy(geom2_);
-        geom1_ = nullptr;
-        geom2_ = nullptr;
-        finishGEOS();
-    }
-
-};
+struct test_capigeosequals_data : public capitest::utility {};
 
 typedef test_group<test_capigeosequals_data> group;
 typedef group::object object;
@@ -127,12 +98,11 @@ void object::test<4>
 {
     GEOSCoordSequence* cs = GEOSCoordSeq_create(5, 2);
 
-    constexpr double nan = std::numeric_limits<double>::quiet_NaN();
     GEOSCoordSeq_setX(cs, 0, 1);
     GEOSCoordSeq_setY(cs, 0, 1);
     for(unsigned int i = 1; i < 4; ++i) {
-        GEOSCoordSeq_setX(cs, i, nan);
-        GEOSCoordSeq_setY(cs, i, nan);
+        GEOSCoordSeq_setX(cs, i, geos::DoubleNotANumber);
+        GEOSCoordSeq_setY(cs, i, geos::DoubleNotANumber);
     }
     GEOSCoordSeq_setX(cs, 4, 1);
     GEOSCoordSeq_setY(cs, 4, 1);
@@ -172,12 +142,10 @@ template<>
 void object::test<6>
 ()
 {
-    const char* wkt1 = "GEOMETRYCOLLECTION(POLYGON ("
-                       "(0 0, 0 4, 4 4, 4 0, 0 0)"
-                       "),"
-                       "POLYGON ("
-                       "(3 3, 3 4, 4 4, 4 3, 3 3)"
-                       "))";
+    const char* wkt1 = "GEOMETRYCOLLECTION("
+                       "POLYGON ((0 0, 0 4, 4 4, 4 0, 0 0)),"
+                       "POLYGON ((3 3, 3 4, 4 4, 4 3, 3 3))"
+                       ")";
 
     geom1_ = GEOSGeomFromWKT(wkt1);
 
