@@ -9,42 +9,15 @@
 #include <cstdlib>
 #include <cmath>
 
+#include "capi_test_utils.h"
+
 namespace tut {
 //
 // Test Group
 //
 
 // Common data used in test cases.
-struct test_capiinterpolate_data {
-    GEOSGeometry* geom1_;
-
-    static void
-    notice(const char* fmt, ...)
-    {
-        std::fprintf(stdout, "NOTICE: ");
-
-        va_list ap;
-        va_start(ap, fmt);
-        std::vfprintf(stdout, fmt, ap);
-        va_end(ap);
-
-        std::fprintf(stdout, "\n");
-    }
-
-    test_capiinterpolate_data()
-        : geom1_(nullptr)
-    {
-        initGEOS(notice, notice);
-    }
-
-    ~test_capiinterpolate_data()
-    {
-        GEOSGeom_destroy(geom1_);
-        geom1_ = nullptr;
-        finishGEOS();
-    }
-
-};
+struct test_capiinterpolate_data : public capitest::utility {};
 
 typedef test_group<test_capiinterpolate_data> group;
 typedef group::object object;
