@@ -99,5 +99,38 @@ void object::test<4>
     ensure(GEOSEqualsExact(expected_, geom3_, 0.00001));
 }
 
+// https://trac.osgeo.org/geos/ticket/1134
+template<>
+template<>
+void object::test<5>
+()
+{
+    geom1_ = GEOSGeomFromWKT("LINESTRING (nan 0.0000000000000000, 0.0000000000000000 1.0000000000000000, 1.0000000000000000 1.0000000000000000, 1.0000000000000000 0.0000000000000000, nan 0.0000000000000000)");
+    geom2_ = GEOSGeomFromWKT("POLYGON ((-86060443046427184.0000000000000000 20820223.5124294497072697, -86060443046427184.0000000000000000 -20820223.5124294497072697, -86060443004786720.0000000000000000 -20820223.5124294497072697, -86060443004786720.0000000000000000 20820223.5124294497072697, -86060443046427184.0000000000000000 20820223.5124294497072697))");
+
+    ensure(geom1_);
+    ensure(geom2_);
+
+    geom3_ = GEOSIntersection(geom1_, geom2_);
+    // No memory leaked
+}
+
+// https://trac.osgeo.org/geos/ticket/1134
+template<>
+template<>
+void object::test<6>
+()
+{
+    geom1_ = GEOSGeomFromWKT("LINESTRING (nan 0.0000000000000000, 0.0000000000000000 nan)");
+    geom2_ = GEOSGeomFromWKT("POLYGON ((-86060443046427184.0000000000000000 20820223.5124294497072697, -86060443046427184.0000000000000000 -20820223.5124294497072697, -86060443004786720.0000000000000000 -20820223.5124294497072697, -86060443004786720.0000000000000000 20820223.5124294497072697, -86060443046427184.0000000000000000 20820223.5124294497072697))");
+
+    ensure(geom1_);
+    ensure(geom2_);
+
+    geom3_ = GEOSIntersection(geom1_, geom2_);
+    // No memory leaked
+}
+
+
 } // namespace tut
 
