@@ -12,6 +12,7 @@
 #include <geos/geom/PrecisionModel.h>
 #include <geos/io/WKTReader.h>
 #include <geos/util/IllegalArgumentException.h>
+#include <geos/constants.h>
 // std
 #include <memory>
 #include <string>
@@ -241,7 +242,7 @@ template<>
 void object::test<15>
 ()
 {
-    ensure_equals(empty_point_->getNumPoints(), (size_t)0);
+    ensure_equals(empty_point_->getNumPoints(), (std::size_t)0);
 }
 
 // Test of getLength() for empty Point
@@ -365,7 +366,7 @@ template<>
 void object::test<28>
 ()
 {
-    ensure_equals(point_->getNumPoints(), (size_t)1);
+    ensure_equals(point_->getNumPoints(), (std::size_t)1);
 }
 
 // Test of getLength() for non-empty Point
@@ -481,7 +482,7 @@ void object::test<38>
     ensure(!p1->equals(p2.get()));
 }
 
-// Test of equals() for non-empty Points with negative coordiantes
+// Test of equals() for non-empty Points with negative coordinates
 template<>
 template<>
 void object::test<39>
@@ -579,5 +580,25 @@ void object::test<45>
     ensure_equals(pt3->getCoordinateDimension(), 3);
 }
 
+
+
+// Test hand-build POINT(NaN NaN)
+template<>
+template<>
+void object::test<46>
+()
+{
+    using geos::geom::Coordinate;
+    using geos::geom::CoordinateArraySequence;
+
+    CoordinateArraySequence* coords = new CoordinateArraySequence();
+    ensure(coords != nullptr);
+    coords->add(Coordinate(geos::DoubleNotANumber, geos::DoubleNotANumber));
+
+    PointAutoPtr point(factory_->createPoint(coords));
+    ensure("point->isEmpty()", point->isEmpty());
+    ensure("point->getCoordinateDimension() == 2", point->getCoordinateDimension() == 2);
+}
+
 } // namespace tut
 
