@@ -1,8 +1,8 @@
 //
 // GEOS Unit Test utilities, extension of TUT Framework namespace
 //
-#ifndef GEOS_TUT_UTILITY_H_INCLUDED
-#define GEOS_TUT_UTILITY_H_INCLUDED
+#pragma once
+
 
 // tut
 #include <tut/tut.hpp>
@@ -69,7 +69,7 @@ typedef geos::geom::MultiLineString const* MultiLineStringCPtr;
 typedef geos::geom::MultiPolygon* MultiPolygonPtr;
 typedef geos::geom::MultiPolygon const* MultiPolygonCPtr;
 
-// prepared geometries always returend as const
+// prepared geometries always returned as const
 typedef geos::geom::prep::PreparedGeometry const* PreparedGeometryPtr;
 
 //
@@ -125,6 +125,7 @@ ensure_equals_geometry(T1 const* lhs, T2 const* rhs)
     ensure(lhs != 0 && rhs != 0 && lhs != rhs);
 }
 
+
 template <typename T>
 inline void
 ensure_equals_geometry(T const* lhs_in, T const* rhs_in, double tolerance = 0.0)
@@ -189,7 +190,21 @@ ensure_equals_geometry(T const* lhs_in, T const* rhs_in, double tolerance = 0.0)
     // }
 }
 
+template<typename T>
+inline void
+ensure_equals_geometry(const T& lhs, const char* rhs, double tolerance = 0.0) {
+    geos::io::WKTReader reader(lhs->getFactory());
+    auto rhs_geom = reader.read(rhs);
+    ensure_equals_geometry(lhs, rhs_geom.get(), tolerance);
+}
 
+template<typename T>
+inline void
+ensure_equals_geometry(const T& lhs, const std::string& rhs, double tolerance = 0.0) {
+    geos::io::WKTReader reader(lhs->getFactory());
+    auto rhs_geom = reader.read(rhs);
+    ensure_equals_geometry(lhs, rhs_geom.get(), tolerance);
+}
 
 template <>
 inline void
@@ -304,7 +319,7 @@ ensure_equals_exact_geometry_xyz(const geos::geom::Geometry *lhs_in,
       return ensure_equals_dims( gln1->getCoordinatesRO(), gln2->getCoordinatesRO(), 3, tolerance);
     }
     else if (dynamic_cast<const Polygon *>(lhs_in)) {
-      assert("Not implemented yet" == 0);
+      ensure("Not implemented yet", 0);
     }
     else if (const GeometryCollection* gc1 = dynamic_cast<const GeometryCollection *>(lhs_in)) {
       const GeometryCollection *gc2 = static_cast<const GeometryCollection *>(rhs_in);
@@ -327,6 +342,49 @@ ensure_equals_geometry_xyz(const T *lhs_in,
     ensure_equals_exact_geometry_xyz(g1.get(), g2.get(), tolerance);
 }
 
+/*
+ * Checks for geometries exactly equal in XY only
+ */
+
+template <typename T> inline void ensure_equals_exact_geometry(const T *lhs_in, const T *rhs_in, double tolerance = 0.0);
+
+template <>
+inline void
+ensure_equals_exact_geometry(const geos::geom::Geometry *lhs_in,
+                                 const geos::geom::Geometry *rhs_in,
+                                 double tolerance)
+{
+    assert(nullptr != lhs_in);
+    assert(nullptr != rhs_in);
+
+    using geos::geom::Point;
+    using geos::geom::LineString;
+    using geos::geom::Polygon;
+    using geos::geom::CoordinateSequence;
+    using geos::geom::GeometryCollection;
+
+    ensure_equals("type id do not match",
+                  lhs_in->getGeometryTypeId(), rhs_in->getGeometryTypeId());
+
+    if (const Point* gpt1 = dynamic_cast<const Point *>(lhs_in)) {
+      const Point *gpt2 = static_cast<const Point *>(rhs_in);
+      return ensure_equals_dims( gpt1->getCoordinatesRO(), gpt2->getCoordinatesRO(), 2, tolerance);
+    }
+    else if (const LineString* gln1 = dynamic_cast<const LineString *>(lhs_in)) {
+      const LineString *gln2 = static_cast<const LineString *>(rhs_in);
+      return ensure_equals_dims( gln1->getCoordinatesRO(), gln2->getCoordinatesRO(), 2, tolerance);
+    }
+    else if (dynamic_cast<const Polygon *>(lhs_in)) {
+      ensure("Not implemented yet", 0);
+    }
+    else if (const GeometryCollection* gc1 = dynamic_cast<const GeometryCollection *>(lhs_in)) {
+      const GeometryCollection *gc2 = static_cast<const GeometryCollection *>(rhs_in);
+      for (unsigned int i = 0; i < gc1->getNumGeometries(); i++) {
+        ensure_equals_exact_geometry(gc1->getGeometryN(i), gc2->getGeometryN(i), tolerance);
+      }
+    }
+}
+
 //
 // Utility functions
 //
@@ -352,5 +410,3 @@ struct wkb_hex_decoder {
 
 } // namespace tut
 
-#endif // #ifndef GEOS_TUT_UTILITY_H_INCLUDED
-
