@@ -29,10 +29,13 @@
 #include <geos/algorithm/MinimumBoundingCircle.h>
 #include <geos/algorithm/distance/DiscreteHausdorffDistance.h>
 #include <geos/algorithm/distance/DiscreteFrechetDistance.h>
+#include <geos/algorithm/hull/ConcaveHull.h>
 #include <geos/geom/util/Densifier.h>
+#include <geos/geom/util/GeometryFixer.h>
 #include <geos/operation/buffer/BufferBuilder.h>
 #include <geos/operation/buffer/BufferOp.h>
 #include <geos/operation/buffer/BufferParameters.h>
+#include <geos/operation/buffer/OffsetCurve.h>
 #include <geos/operation/linemerge/LineMerger.h>
 #include <geos/operation/distance/DistanceOp.h>
 #include <geos/operation/intersection/RectangleIntersection.h>
@@ -41,6 +44,9 @@
 #include <geos/operation/valid/MakeValid.h>
 #include <geos/operation/overlayng/OverlayNG.h>
 #include <geos/operation/polygonize/Polygonizer.h>
+#include <geos/operation/polygonize/BuildArea.h>
+#include <geos/operation/overlayng/CoverageUnion.h>
+#include <geos/operation/union/CoverageUnion.h>
 #include <geos/precision/GeometryPrecisionReducer.h>
 #include <geos/simplify/DouglasPeuckerSimplifier.h>
 #include <geos/simplify/TopologyPreservingSimplifier.h>
@@ -138,6 +144,21 @@ GeomFunction::init()
             PrecisionModel pm(d);
             return new Result( geos::precision::GeometryPrecisionReducer::reduce( *geom, pm ) );
         });
+    add("reducePrecisionKeepCollapsed", 1, 1, Result::typeGeometry, catGeom,
+        "reduce precision of geometry to a precision scale factor",
+        [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
+            (void)geomB;  // prevent unused variable warning
+            PrecisionModel pm(d);
+            return new Result( geos::precision::GeometryPrecisionReducer::reduceKeepCollapsed( *geom, pm ) );
+        });
+    add("reducePrecisionPointwise", 1, 1, Result::typeGeometry, catGeom,
+        "reduce precision of geometry to a precision scale factor",
+        [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
+            (void)geomB;  // prevent unused variable warning
+            PrecisionModel pm(d);
+            return new Result( geos::precision::GeometryPrecisionReducer::reducePointwise( *geom, pm ) );
+        });
+
     add("reverse", 1, 0, Result::typeGeometry, catGeom,
         "reverse geometry",
         [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
@@ -171,11 +192,18 @@ GeomFunction::init()
             (void) geomB; (void)d;  // prevent unused variable warning
             return new Result( geom->isValid() );
         });
-    add("makeValid", Result::typeGeometry, catValid,
+    add("fixInvalid", 1, 0, Result::typeGeometry, catValid,
+        "fix invalid geometry to be valid",
+        [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
+            (void) geomB; (void)d;  // prevent unused variable warning
+            return new Result( geos::geom::util::GeometryFixer::fix( geom.get() ) );
+       });
+    add("makeValid", 1, 0, Result::typeGeometry, catValid,
+        "make geometry valid (original algorithm)",
         [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
             (void) geomB; (void)d;  // prevent unused variable warning
             return new Result( geos::operation::valid::MakeValid().build( geom.get() ) );
-        });
+       });
 //-------------------------------------
 
     add("boundary", Result::typeGeometry, catConst,
@@ -190,6 +218,16 @@ GeomFunction::init()
             return new Result( geom->buffer( d ) );
         });
     add("offsetCurve", 1, 1, Result::typeGeometry,
+        catConst, "compute the offset curve of geometry by a distance",
+        [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
+            (void) geomB;  // prevent unused variable warning
+            geos::operation::buffer::BufferParameters bp;
+
+            geos::operation::buffer::OffsetCurve oc(*geom, d, bp);
+            std::unique_ptr<Geometry> g3 = oc.getCurve();
+            return new Result( g3.release() );
+        });
+    add("OLDoffsetCurve", 1, 1, Result::typeGeometry,
         catConst, "compute the offset curve of geometry by a distance",
         [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
             (void) geomB;  // prevent unused variable warning
@@ -213,6 +251,21 @@ GeomFunction::init()
             (void) geomB; (void)d;  // prevent unused variable warning
             return new Result( geom->convexHull() );
         });
+    add("concaveHull", Result::typeGeometry, catConst,
+        [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
+            (void) geomB; (void)d;  // prevent unused variable warning
+            geos::algorithm::hull::ConcaveHull hull(geom.get());
+            hull.setMaximumEdgeLengthRatio( d );
+            return new Result( hull.getHull() );
+        });
+    add("concaveHullHoles", Result::typeGeometry, catConst,
+        [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
+            (void) geomB; (void)d;  // prevent unused variable warning
+            geos::algorithm::hull::ConcaveHull hull(geom.get());
+            hull.setMaximumEdgeLengthRatio( d );
+            hull.setHolesAllowed(true);
+            return new Result( hull.getHull() );
+        });
 
     add("densify", 1, 1, Result::typeGeometry, catConst,
         "densify geometry to a distance ",
@@ -310,6 +363,13 @@ GeomFunction::init()
             }
             return new Result( std::move(geoms) ) ;
         });
+    add("buildArea", Result::typeGeometry, catConst,
+        [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
+            (void) geomB; (void)d;  // prevent unused variable warning
+            geos::operation::polygonize::BuildArea builder;
+            auto result = builder.build(geom.get());
+            return new Result( std::move(result) ) ;
+        });
     add("simplifyDP", 1, 1, Result::typeGeometry, catConst,
         "simplify geometry using Douglas-Peucker with a distance tolerance",
         [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
@@ -336,6 +396,12 @@ GeomFunction::init()
             (void)d;  // prevent unused variable warning
             return new Result( geom->covers( geomB.get() ) );
         });
+    add("equals", 2, 0, Result::typeBool, catRel,
+        "test if geometry A equals geometry B",
+        [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
+            (void)d;  // prevent unused variable warning
+            return new Result( geom->equals( geomB.get() ) );
+        });
     add("intersects", 2, 0, Result::typeBool, catRel,
         "test if geometry A and B intersect",
         [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
@@ -468,6 +534,18 @@ GeomFunction::init()
             (void)d;  // prevent unused variable warning
             return new Result( geom->Union( geomB.get() ) );
         });
+    add("unionCoverageNG", 1, 0, Result::typeGeometry, catOverlay,
+        "union a polygonal coverage",
+        [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
+            (void)geomB; (void)d;  // prevent unused variable warning
+            return new Result( geos::operation::overlayng::CoverageUnion::geomunion(geom.get()) );
+        });
+    add("unionCoverage", 1, 0, Result::typeGeometry, catOverlay,
+        "union a polygonal coverage",
+        [](const std::unique_ptr<Geometry>& geom, const std::unique_ptr<Geometry>& geomB, double d)->Result* {
+            (void)geomB; (void)d;  // prevent unused variable warning
+            return new Result( geos::operation::geounion::CoverageUnion::Union(geom.get()) );
+        });
 
     add("differenceSR", 2, 1, Result::typeGeometry, catOverlay,
         "compute difference of geometry A from B, snap-rounding to a precision scale factor",
